import type MountedRouter from './mounted-router';
import type { Header } from './navigator-route';
import type NavigatorRoute from './navigator-route';
import type { RouteableState } from './routeable';
export declare type MountedNodeSet = {
    [key: string]: MountedNode;
};
/**
 * A MountedNode is an internal/private class that represents a node in the router tree that
 * has been fully initialized (similar to components in ember that have been fully rendered
 * into the DOM, or "mounted" components in React).
 *
 * Apps should not import, subclass, or interact with this class; instead, apps should
 * define subclasses of {NavigatorRoute}, which is the public API for customizing
 * behavior when the route is mounted.
 */
export declare class MountedNode {
    childNodes: MountedNodeSet;
    routeableState: RouteableState;
    route: NavigatorRoute;
    id: number;
    mountedRouter: MountedRouter;
    parentNode: MountedNode | null;
    constructor(mountedRouter: MountedRouter, parentNode: MountedNode | null, routeableState: RouteableState);
    update(routeableState: RouteableState): void;
    mount(): void;
    unmount(): void;
    resolve(name: string): typeof NavigatorRoute | null;
    get componentName(): string;
    get routeName(): string;
    get key(): string;
    get params(): Record<string, unknown>;
    get isRouter(): boolean;
    getHeaderConfig(): Header | null;
}
