import type { NavigateParams, PopParams } from './actions/types';
import type { MountedNode } from './mounted-node';
import type { RouteableState } from './routeable';
export declare type Header = {
    title?: string;
};
/**
 * NavigatorRoute is part of the public API of ember-navigator; it is a class
 * that is meant to be subclassed with various lifecycle hooks that can be
 * overridden in the subclass.
 */
export default class NavigatorRoute {
    node: MountedNode;
    header?: Header;
    constructor(node: MountedNode);
    static create(props: {
        node: MountedNode;
    }): NavigatorRoute;
    navigate(options: NavigateParams): void;
    pop(options?: PopParams): void;
    update(_state: RouteableState): void;
    /**
     * Returns the params hash passed to this route (mostly via the `navigate()` method)
     */
    get params(): Record<string, unknown>;
    /**
     * Returns the navigation key that uniquely identifies the route within a router tree;
     * this is a value that is either passed in as an option to `navigate()`, or is
     * auto-generated if no such value is passed to `navigate()`
     */
    get key(): string;
    /**
     * Returns the name of this route as specified in the mapping DSL (e.g. `route('foo')`)
     */
    get name(): string;
    /**
     * Returns the immediate parent route or router. For example, if this is the 3rd route
     * within a stack router, `parent()` will return the 2nd NavigatorRoute in the stack.
     */
    get parent(): NavigatorRoute | null;
    /**
     * Returns the closest parent of the provided name.
     */
    parentNamed(name: string): NavigatorRoute | null;
    /**
     * Returns the nearest parent router, e.g. the stack router that this route is mounted in.
     */
    get parentRouter(): NavigatorRoute | null;
    /**
     * Returns the parent route, and null if there is no parent, or the parent is a router.
     */
    get parentRoute(): NavigatorRoute | null;
    /**
     * `mount` is called after transitioning to a new route, or pushing a stack frame;
     * Within this hook, you can access `this.params` to access any params passed into
     * this route (such as model IDs or any other information)
     */
    mount(): void;
    /**
     * `unmount` is called after the route has been removed from the routing tree.
     */
    unmount(): void;
}
