import type { RouterActions } from './actions/types';
import type { MountedNode } from './mounted-node';
import type { InitialStateOptions, RouteableReducer, RouterState, RouteState, UnhandledReducerResult } from './routeable';
export declare type RouteOptions = {
    componentName?: string;
};
/**
 * This is the reducer object returned by the `route()` function in the mapping DSL, e.g.
 *
 *    [
 *       route('home'),
 *       route('customer', { path: 'customer/:customer_id' }),
 *    ]
 *
 * It represents a leaf (child-less) route in the routing tree.
 */
export declare class RouteReducer implements RouteableReducer {
    name: string;
    children: RouteableReducer[];
    options: RouteOptions;
    isRouter: false;
    componentName: string;
    constructor(name: string, options: RouteOptions);
    getInitialState(options?: InitialStateOptions): RouteState;
    dispatch(_action: RouterActions, _state: RouterState): UnhandledReducerResult;
    reconcile(routeState: RouteState, mountedNode: MountedNode): void;
}
